summaryrefslogtreecommitdiffstats
path: root/src/qtraylabel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/qtraylabel.h')
-rw-r--r--src/qtraylabel.h72
1 files changed, 36 insertions, 36 deletions
diff --git a/src/qtraylabel.h b/src/qtraylabel.h
index 1ae83bc..7fb645c 100644
--- a/src/qtraylabel.h
+++ b/src/qtraylabel.h
@@ -22,15 +22,15 @@
#ifndef _QTRAYLABEL_H
#define _QTRAYLABEL_H
-#include <qlabel.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qpixmap.h>
-#include <qtimer.h>
-#include <qtextstream.h>
-#include <qsettings.h>
-#include <qevent.h>
-#include <qsize.h>
+#include <tqlabel.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqpixmap.h>
+#include <tqtimer.h>
+#include <tqtextstream.h>
+#include <tqsettings.h>
+#include <tqevent.h>
+#include <tqsize.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
@@ -39,18 +39,18 @@
#include <sys/types.h>
#include <unistd.h>
-class QMouseEvent;
-class QDragEnterEvent;
-class QPoint;
+class TQMouseEvent;
+class TQDragEnterEvent;
+class TQPoint;
-class QTrayLabel : public QLabel
+class TQTrayLabel : public TQLabel
{
Q_OBJECT
public:
- QTrayLabel(Window w, QWidget* p = 0, const QString& text = QString::null);
- QTrayLabel(const QStringList& argv, pid_t pid, QWidget* parent = 0);
- virtual ~QTrayLabel();
+ TQTrayLabel(Window w, TQWidget* p = 0, const TQString& text = TQString::null);
+ TQTrayLabel(const TQStringList& argv, pid_t pid, TQWidget* parent = 0);
+ virtual ~TQTrayLabel();
// Accessors
Window dockedWindow(void) const { return mDockedWindow; }
@@ -59,18 +59,18 @@ public:
bool isWithdrawn(void) const { return mWithdrawn; }
bool isDockWhenMinimized(void) const { return mDockWhenMinimized; }
- QString appName(void) const { return mProgName[0]; }
- virtual void setAppName(const QString& prog) { mProgName[0] = prog; }
- QString appClass(void) const { return mClass; }
- QString appTitle(void) const { return mTitle; }
- QPixmap appIcon(void) const { return mAppIcon; }
+ TQString appName(void) const { return mProgName[0]; }
+ virtual void setAppName(const TQString& prog) { mProgName[0] = prog; }
+ TQString appClass(void) const { return mClass; }
+ TQString appTitle(void) const { return mTitle; }
+ TQPixmap appIcon(void) const { return mAppIcon; }
// Pass on all events through this interface
bool x11EventFilter(XEvent * event);
// Session Management
- virtual bool saveState(QSettings& settings);
- virtual bool restoreState(QSettings& settings);
+ virtual bool saveState(TQSettings& settings);
+ virtual bool restoreState(TQSettings& settings);
public slots:
void dock(void); // puts us in the system tray
@@ -80,7 +80,7 @@ public slots:
void toggleShow(void) // convenience slot
{ if (mWithdrawn) map(); else withdraw(); }
void close(void); // close the docked window
- void setTrayIcon(const QString& icon); // sets custom icon
+ void setTrayIcon(const TQString& icon); // sets custom icon
// and some property setters
virtual void setSkipTaskbar(bool skip); // skip the taskbar
@@ -91,20 +91,20 @@ protected slots:
void scanClients(void); // scans existing client connections
signals:
- void clicked(const ButtonState&, const QPoint&);
- void docked(QTrayLabel *); // emitted when we get docked
+ void clicked(const ButtonState&, const TQPoint&);
+ void docked(TQTrayLabel *); // emitted when we get docked
void docked(void); // emitted when we get docked
- void undocked(QTrayLabel *); // emitted when we get undocked
+ void undocked(TQTrayLabel *); // emitted when we get undocked
void undocked(void); // emitted when we get undock
// window are monitoring dies
void sysTrayDestroyed(void); // emitted when the system tray disappears
protected:
// reimplement these event handlers in subclass as needed
- virtual void mouseReleaseEvent(QMouseEvent *event);
- virtual void dragEnterEvent(QDragEnterEvent *event);
+ virtual void mouseReleaseEvent(TQMouseEvent *event);
+ virtual void dragEnterEvent(TQDragEnterEvent *event);
- // the events that follow are events of the docked window (NOT QTrayLabel)
+ // the events that follow are events of the docked window (NOT TQTrayLabel)
virtual void updateIcon(void); // updates the icon
virtual void updateTitle(void); // sets the tooltip
virtual void balloonText(void); // balloons text
@@ -140,19 +140,19 @@ private:
// Member variables
long mDesktop; // desktop on which the window is being shown
- QLabel *mBalloon; // tooltip text simulator
- QString mCustomIcon; // CustomIcon of the docked application
+ TQLabel *mBalloon; // tooltip text simulator
+ TQString mCustomIcon; // CustomIcon of the docked application
Window mDockedWindow; // the window which is being docked
int mBalloonTimeout;
bool mDocked, mWithdrawn, mSkippingTaskbar;
bool mDockWhenMinimized;
- QString mTitle, mClass; // Title and hint of mDockedWindow
- QPixmap mAppIcon; // The current app icon (may not be same as pixmap())
+ TQString mTitle, mClass; // Title and hint of mDockedWindow
+ TQPixmap mAppIcon; // The current app icon (may not be same as pixmap())
XSizeHints mSizeHint; // SizeHint of mDockedWindow
- QTimer mRealityMonitor; // Helps us sync up with reality
- QStringList mProgName; // The program whose window we are docking
+ TQTimer mRealityMonitor; // Helps us sync up with reality
+ TQStringList mProgName; // The program whose window we are docking
pid_t mPid; // The PID of program whose window we are docking
Window mSysTray; // System tray window id